NAME
Net::CalDAV::FindEntry - find calendar entries overlapping a timespan
SYNOPSIS
use 5.020;
my $cal = Net::CalDAV::FindEntry->new(
user => 'AzureDiamond',
password => 'hunter2',
calendar_url => 'https://example.com/calendar/',
);
if( 0 ) {
$cal->ua->verify_SSL(0);
}
my @relevant_events = $cal->get_events(
after => '2026-09-01T09:00:00',
before => '2026-09-01T16:00:00',
calendar => 'Work'
);
for ( sort { $a->{start} cmp $b->{start} } @relevant_events) {
say(join( "-", $_->{start}, $_->{title} ));
}
METHODS
NAME
Net::CalDAVTalk::Extended - convenience functions and bugfixes for Net::CalDAVTalk
METHODS
->GetEventLinksEx
my $links = $cal->GetEventLinksEx( after => '...', before => '...' );
Allows filtering for events within a time range without truncating the before and after values to whole days.
->GetEventsEx
Like ->GetEvents but expands all recurrences to the actual timespan instead of leaving that to the calling client. This requires RFC 4791 support by the CalDAV server.
REPOSITORY
The public repository of this module is https://github.com/Corion/Net-CalDAV-FindEntry.
SUPPORT
The public support forum of this module is https://perlmonks.org/.
BUG TRACKER
Please report bugs in this module via the Github bug queue at https://github.com/Corion/Net-CalDAV-FindEntry/issues
AUTHOR
Max Maischein corion@cpan.org
LICENSE
This module is released under the same terms as Perl itself.